@@ -26,7 +26,9 @@
 BaseResource::BaseResource(ToolWindow *toolwindow)
 {
 
-	bbtool=toolwindow;
+  bbtool=toolwindow;
+  style.style_filename=NULL;
+  style.conf_filename=NULL;
 
   if (bbtool->default_config)
   {
